import { select, csv, scaleLinear, scaleBand, max, 
        axisLeft, axisBottom, format } from 'd3';

const svg=select('svg');
const height=parseFloat(svg.attr('height'));
const width=parseFloat(svg.attr('width'));

const render = data => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  
  const margin ={top: 50, left:150, bottom:70, right:40};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth]);
  //console.log(xScale.domain());
  //console.log(xScale.range());
  
  const yScale = scaleBand()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.1);
  //console.log(yScale.domain());
  //console.log(yScale.range());
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  
  //const yAxis = axisLeft(yScale);
  //yAxis(g.append('g'));
  g.append('g').call(axisLeft(yScale))
  	.selectAll('.domain, .tick line')
  		.remove();
  
  //console.log(typeof(format('.3s')(1000000)));
  
  const xAxisTickFormat = number => 
  	format('.3s')(number)
  		.replace('G', 'B');
  
  const xAxis = axisBottom(xScale)
  	.tickFormat(xAxisTickFormat)
  	.tickSize(-innerHeight);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain')
  	.remove();
  
  xAxisG.append('text')
  	.attr('class','axis-label')
  	.attr('y', 50)
  	.attr('x', innerWidth/2)
  	.attr('fill', 'black')
    .text('Population');
  
  
  g.selectAll('rect').data(data)
  .enter().append('rect')
  	.attr('y', d => yScale(yValue(d)))
  	.attr('width', d => xScale(xValue(d)))
  	.attr('height', yScale.bandwidth());
  
  g.append('text')
  	.attr('class','title')
  	.attr('y', -2)
  	.text('Top 10 most populous countries');;
};

csv ('data.csv').then(data=>{
	data.forEach(d=> {
    d.population=+d.population * 1000;
  });
  //console.log(data);
  render(data);
});

